@@ -148,3 +148,14 @@ def topological_test(thelist, tester):
         last_index = index
     return True
 
+def is_ordered(thelist, reverse=False):
+    if reverse:
+        for index in range(1, len(thelist)):
+            if thelist[index] > thelist[index-1]:
+                return False
+        return True
+    else:
+        for index in range(1, len(thelist)):
+            if thelist[index] < thelist[index-1]:
+                return False
+        return True
